@@ -9,6 +9,7 @@
 #pragma once
 
 #include "fetchjob.h"
+#include "event.h"
 #include "kgapicalendar_export.h"
 
 #include <QScopedPointer>
@@ -143,6 +144,18 @@ public:
      */
     ~EventFetchJob() override;
 
+    /**
+     * @brief Sets the types of events to retrieve.
+     *
+     * Default set is EventType::Default, EventType::FocusTime and EventType::OutOfOffice.
+     */
+    void setEventTypes(const QList<Event::EventType> eventTypes);
+
+    /**
+     * @brief Returns the types of events to retrieve.
+     */
+    QList<Event::EventType> eventTypes() const;
+
     /**
      * @brief Sets fulltext filter.
      *
@@ -232,6 +245,14 @@ protected:
      */
     ObjectsList handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData) override;
 
+    /**
+     * @brief KGAPI2::Job::handleError implementation
+     *
+     * @param errorCode
+     * @param rawData
+     */
+    bool handleError(int errorCode, const QByteArray &rawData) override;
+
 private:
     class Private;
     QScopedPointer<Private> const d;
