@@ -1,33 +1,18 @@
 /*
- * Copyright (C) 2019  David Barchiesi <david@barchie.si>
+ * SPDX-FileCopyrightText: 2019 David Barchiesi <david@barchie.si>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "drivessearchquery.h"
 #include "utils.h"
 
-#include <QString>
 #include <QDateTime>
+#include <QString>
 
 using namespace KGAPI2;
 using namespace KGAPI2::Drive;
 
-
 QString DrivesSearchQuery::fieldToString(Field field)
 {
     switch (field) {
@@ -51,7 +36,7 @@ QString DrivesSearchQuery::valueToString(DrivesSearchQuery::Field field, const Q
 {
     switch (field) {
     case Name:
-        return QStringLiteral("'%1'").arg(var.toString().replace(QLatin1Char('\''), QLatin1String("\\\'")));
+        return QStringLiteral("'%1'").arg(var.toString().replace(QLatin1Char('\''), QLatin1StringView("\\\'")));
     case Hidden:
         return Utils::bool2Str(var.toBool());
     case MemberCount:
