@@ -57,7 +57,7 @@ void TaskListCreateJob::start()
     const auto rawHeaderList = request.rawHeaderList();
     headers.reserve(rawHeaderList.size());
     for (const QByteArray &str : std::as_const(rawHeaderList)) {
-        headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
+        headers << QLatin1StringView(str) + QLatin1StringView(": ") + QLatin1StringView(request.rawHeader(str));
     }
 
     enqueueRequest(request, rawData, QStringLiteral("application/json"));
